##  Getting the Data Model of Your Workspace
The data model of your workspace provides the meta model attributes in JSON format. Each fact sheet attribute is uniquely identified by an attribute key, also known as the technical name. To learn more about attribute keys in the meta model configuration, see [Attribute Key](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__attribute_key).
To get the data model of your workspace, in the upper-right corner of the processor page, click the three-dot icon > Get Data Model.
The data model in JSON format is returned in the Output Log section. You can copy attribute keys from here and use them in your configurations.
![Getting the Data Model of a Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d82bd7a441014b8d2f9c0c0874f99_LowRes.png)
Getting the Data Model of a Workspace
